@@ -5,8 +5,8 @@
 ;; Author:   Dmitry Gutov <dmitry@gutov.dev>
 ;; URL:      https://github.com/dgutov/diff-hl
 ;; Keywords: vc, diff
-;; Package-Version: 20260223.1553
-;; Package-Revision: bdb36417e3dc
+;; Package-Version: 20260225.2247
+;; Package-Revision: bb9af85441b0
 ;; Package-Requires: ((cl-lib "0.2") (emacs "26.1"))
 
 ;; This file is part of GNU Emacs.
@@ -486,12 +486,14 @@ It can be a relative expression as well, such as \"HEAD^\" with Git, or
          (hide-staged (and (eq backend 'Git) (not diff-hl-show-staged-changes))))
     (when backend
       (let ((state (vc-state file backend))
-            ;; Workaround for debbugs#78946.
+            ;; Workaround for debbugs#78946 for the `thread' async update method.
             ;; This is fiddly, but we basically allow the thread to start, while
             ;; prohibiting the async process call inside.
-            ;; That still makes it partially async.
-            (diff-hl-update-async (and (not (eq window-system 'ns))
-                                       (eq diff-hl-update-async t))))
+            ;; That still makes it partially async on macOS.
+            ;; Or just use "simple async" if your Emacs is new enough.
+            (diff-hl-update-async (or (and (eq diff-hl-update-async 'thread)
+                                           (not (eq window-system 'ns)))
+                                      (eq diff-hl-update-async t))))
         (cond
          ((and
            (not diff-hl-highlight-reference-function)
